changeset 46899:f00337f04e78

Use find-file-hook instead of find-file-hooks.
author Stefan Monnier <monnier@iro.umontreal.ca>
date Thu, 15 Aug 2002 00:48:20 +0000
parents 0b0448a9c183
children 3c3d686b25fa
files lisp/elide-head.el lisp/font-core.el lisp/obsolete/hilit19.el lisp/play/meese.el lisp/saveplace.el lisp/smerge-mode.el lisp/uniquify.el lisp/which-func.el
diffstat 8 files changed, 11 insertions(+), 11 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/font-core.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/font-core.el	Thu Aug 15 00:48:20 2002 +0000
@@ -290,7 +290,7 @@
 ;; hook is run, the major mode is in the process of being changed and we do not
 ;; know what the final major mode will be.  So, `font-lock-change-major-mode'
 ;; only (a) notes the name of the current buffer, and (b) adds our function
-;; `turn-on-font-lock-if-enabled' to the hook variables `find-file-hooks' and
+;; `turn-on-font-lock-if-enabled' to the hook variables `find-file-hook' and
 ;; `post-command-hook' (for buffers that are not visiting files).  By the time
 ;; the functions on the first of these hooks to be run are run, the new major
 ;; mode is assumed to be in place.  This way we get a Font Lock function run
--- a/lisp/obsolete/hilit19.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/obsolete/hilit19.el	Thu Aug 15 00:48:20 2002 +0000
@@ -956,7 +956,7 @@
 
 (global-set-key [?\C-\S-l] 'hilit-repaint-command)
 
-(add-hook 'find-file-hooks 'hilit-find-file-hook t)
+(add-hook 'find-file-hook 'hilit-find-file-hook t)
 
 (eval-when-compile (require 'gnus))	; no compilation gripes
 
--- a/lisp/play/meese.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/play/meese.el	Thu Aug 15 00:48:20 2002 +0000
@@ -31,7 +31,7 @@
 	    (insert-file-contents buffer-file-name t))
 	  (rename-buffer (file-name-nondirectory buffer-file-name))))))
 
-(add-hook 'find-file-hooks 'protect-innocence-hook)
+(add-hook 'find-file-hook 'protect-innocence-hook)
 (provide 'meese)
 
 ;;; meese.el ends here
--- a/lisp/saveplace.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/saveplace.el	Thu Aug 15 00:48:20 2002 +0000
@@ -230,7 +230,7 @@
   (if save-place-loaded
       (save-place-alist-to-file)))
 
-(add-hook 'find-file-hooks 'save-place-find-file-hook t)
+(add-hook 'find-file-hook 'save-place-find-file-hook t)
 
 (add-hook 'kill-emacs-hook 'save-place-kill-emacs-hook)
 
--- a/lisp/smerge-mode.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/smerge-mode.el	Thu Aug 15 00:48:20 2002 +0000
@@ -4,7 +4,7 @@
 
 ;; Author: Stefan Monnier <monnier@cs.yale.edu>
 ;; Keywords: merge diff3 cvs conflict
-;; Revision: $Id: smerge-mode.el,v 1.14 2001/07/31 08:28:43 gerd Exp $
+;; Revision: $Id: smerge-mode.el,v 1.15 2001/11/15 01:25:35 monnier Exp $
 
 ;; This file is part of GNU Emacs.
 
@@ -38,7 +38,7 @@
 ;;   	 (goto-char (point-min))
 ;;   	 (when (re-search-forward "^<<<<<<< " nil t)
 ;;   	   (smerge-mode 1))))
-;;   (add-hook 'find-file-hooks 'sm-try-smerge t)
+;;   (add-hook 'find-file-hook 'sm-try-smerge t)
 
 ;;; Todo:
 
--- a/lisp/uniquify.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/uniquify.el	Thu Aug 15 00:48:20 2002 +0000
@@ -352,7 +352,7 @@
 ;; generate-new-buffer, which is called only by Lisp functions
 ;; create-file-buffer and rename-uniquely.  Rename-uniquely generally
 ;; isn't used for buffers visiting files, so it's sufficient to hook
-;; rename-buffer and create-file-buffer.  (Setting find-file-hooks isn't
+;; rename-buffer and create-file-buffer.  (Setting find-file-hook isn't
 ;; sufficient.)
 
 (defadvice rename-buffer (after rename-buffer-uniquify activate)
--- a/lisp/which-func.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/which-func.el	Thu Aug 15 00:48:20 2002 +0000
@@ -58,7 +58,7 @@
 ;; Peter Eisenhauer <pipe@fzi.de>
 ;;     Bug fixing in case nested indexes.
 ;; Terry Tateyama   <ttt@ursa0.cs.utah.edu>
-;;     Suggestion to use find-file-hooks for first imenu
+;;     Suggestion to use find-file-hook for first imenu
 ;;     index building.
 
 ;;; Code:
@@ -131,7 +131,7 @@
 (make-variable-buffer-local 'which-func-mode)
 ;;(put 'which-func-mode 'permanent-local t)
 
-(add-hook 'find-file-hooks 'which-func-ff-hook t)
+(add-hook 'find-file-hook 'which-func-ff-hook t)
 
 (defun which-func-ff-hook ()
   "File find hook for Which Function mode.
--- a/lisp/elide-head.el	Thu Aug 15 00:46:09 2002 +0000
+++ b/lisp/elide-head.el	Thu Aug 15 00:48:20 2002 +0000
@@ -33,7 +33,7 @@
 ;; elision.
 
 ;; You might add `elide-head' to appropriate major mode hooks or to
 ;; `find-file-hooks'.  Please do not do this in site init files.  If
 ;; you do, information may be hidden from users who don't know it
 ;; already.
 
@@ -78,7 +78,7 @@
 The header is made invisible with an overlay.  With a prefix arg, show
 an elided material again.
 
-This is suitable as an entry on `find-file-hooks' or appropriate mode hooks."
+This is suitable as an entry on `find-file-hook' or appropriate mode hooks."
   (interactive "P")
   (if arg
       (elide-head-show)
@@ -33,7 +33,7 @@
 
 ;; You might add `elide-head' to appropriate major mode hooks or to
-;; `find-file-hooks'.  Please do not do this in site init files.  If
+;; `find-file-hook'.  Please do not do this in site init files.  If
 ;; you do, information may be hidden from users who don't know it
 ;; already.